<?php
App::uses('AppController', 'Controller');

class ApiLogsController extends AppController {

	/**
	 * Paginator defaults for admin.
	 *
	 * @var array
	 */
	public $adminPaginate = array(
		'sort' => 'created',
		'limit' => 25
	);

	public function beforeFilter() {
		parent::beforeFilter();

		if (CakeSession::read('Auth.User.UserGroup.id') != '1') {
			return $this->redirect('/admin');
		}
	}

	protected function _adminFilterFields() {
		$fields = parent::_adminFilterFields();

		unset($fields['ApiLog.id']);

		$fields['ApiLog.model'] = array(
			'label' => 'Model',
			'type' => 'string',
			'compare' => array(
				'ApiLog.model' => '%%%s%%'
			)
		);

		$fields['ApiLog.foreign_id'] = array(
			'label' => 'Model Id',
			'type' => 'string',
			'compare' => array(
				'ApiLog.foreign_id' => '%s'
			)
		);

		$fields['ApiLog.method'] = array(
			'label' => 'API Method',
			'type' => 'string',
			'compare' => array(
				'ApiLog.method' => '%%%s%%'
			)
		);
		$fields['ApiLog.failed'] = array(
			'label' => 'Failed?',
			'type' => 'boolean',
			'compare' => array(
				'ApiLog.failed' => '%s'
			)
		);

		return $fields;
	}

	protected function _adminIndexColumns() {
		$columns = parent::_adminIndexColumns();

		$extraColumns = array(
			'ApiLog.model' => array(
				'type' => 'string',
				'label' => 'Model'
			),
			'ApiLog.foreign_id' => array(
				'type' => 'integer',
				'label' => 'Model Id'
			),
			'ApiLog.method' => array(
				'type' => 'string',
				'label' => 'Method'
			),

			'ApiLog.status' => array(
				'type' => 'string',
				'label' => 'Status'
			),
		);

		return ArrayUtil::addAfter($columns, 'ApiLog.id', $extraColumns);
	}

	protected function _adminIndexActions() {
		return array(
			'Delete',
			'Admin View'
		);
	}

	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();

		$foreignId = $this->request->data['ApiLog']['foreign_id'];
		$fields['ApiLog.foreign_id']['options'][$foreignId] = $foreignId;

		return $fields;
	}

	protected function _adminFormToolbar($id = null) {
		return array();
	}
}
